@@ -14,23 +14,8 @@ TEST_MODULES = frozenset('srv db polish opf css docx cfi matcher icu smartypants
 
 class TestImports(unittest.TestCase):
 
-    def test_import_of_all_python_modules(self):
+    def base_check(self, base, exclude_packages, exclude_modules):
         import importlib
-        exclude_modules = {'calibre.gui2.dbus_export.demo', 'calibre.gui2.dbus_export.gtk'}
-        exclude_packages = {'calibre.devices.mtp.unix.upstream'}
-        if not iswindows:
-            exclude_modules |= {'calibre.utils.iphlpapi', 'calibre.utils.open_with.windows', 'calibre.devices.winusb'}
-            exclude_packages |= {'calibre.utils.winreg'}
-        if not isosx:
-            exclude_modules.add('calibre.utils.open_with.osx')
-        if not islinux:
-            exclude_modules |= {
-                    'calibre.utils.dbus_service', 'calibre.linux',
-                    'calibre.utils.linux_trash', 'calibre.utils.open_with.linux',
-                    'calibre.gui2.linux_file_dialogs'
-            }
-            exclude_packages.add('calibre.gui2.dbus_export')
-        base = os.path.join(SRC, 'calibre')
         import_base = os.path.dirname(base)
         count = 0
         for root, dirs, files in os.walk(base):
@@ -50,7 +35,26 @@ class TestImports(unittest.TestCase):
                     continue
                 importlib.import_module(full_module_name)
                 count += 1
-        self.assertGreater(count, 1000)
+        return count
+
+    def test_import_of_all_python_modules(self):
+        exclude_modules = {'calibre.gui2.dbus_export.demo', 'calibre.gui2.dbus_export.gtk'}
+        exclude_packages = {'calibre.devices.mtp.unix.upstream'}
+        if not iswindows:
+            exclude_modules |= {'calibre.utils.iphlpapi', 'calibre.utils.open_with.windows', 'calibre.devices.winusb'}
+            exclude_packages |= {'calibre.utils.winreg'}
+        if not isosx:
+            exclude_modules.add('calibre.utils.open_with.osx')
+        if not islinux:
+            exclude_modules |= {
+                    'calibre.utils.dbus_service', 'calibre.linux',
+                    'calibre.utils.linux_trash', 'calibre.utils.open_with.linux',
+                    'calibre.gui2.linux_file_dialogs'
+            }
+            exclude_packages.add('calibre.gui2.dbus_export')
+        self.assertGreater(self.base_check(os.path.join(SRC, 'odf'), exclude_packages, exclude_modules), 10)
+        base = os.path.join(SRC, 'calibre')
+        self.assertGreater(self.base_check(base, exclude_packages, exclude_modules), 1000)
 
 
 def find_tests(which_tests=None):
@@ -121,6 +125,9 @@ def find_tests(which_tests=None):
         a(find_tests())
         from calibre.library.comments import find_tests
         a(find_tests())
+        from calibre.ebooks.compression.palmdoc import find_tests
+        a(find_tests())
+
         a(unittest.defaultTestLoader.loadTestsFromTestCase(TestImports))
     if ok('dbcli'):
         from calibre.db.cli.tests import find_tests
